Ymvas - handle your life like a developer!

Installation:
```bash
pip3 install ymvas
```

Usage:

```bash
Usage :
    ym {command}   |  info,clone,config,compile
    ym --{command} |  Is not allowed!

File based commands placed like this:
    ~/repo/.ymvas/commands/install.bash
    ~/repo/.ymvas/commands/install.py
    ~/repo/.ymvas/commands/install.sh

Can be easly executed like this:
    ym install
```
